# Remaining issues:
#
# Upstream Issues
#
# - enable simpleSAMLphp modules through (main) config file
#   ISSUE: http://code.google.com/p/simplesamlphp/issues/detail?id=475
#
# - more configurable paths in config.php
#   ISSUE: http://code.google.com/p/simplesamlphp/issues/detail?id=349
#
# Packaging Issues
#
# - Follow packaging guidelines for SSL certificates, see
#   http://fedoraproject.org/wiki/PackagingDrafts/Certificates
#
# - Make sure SELinux does not interfere with reading the certificates from 
#   /etc/pki/simplesamlphp/. Should be sufficient to just make them owned by
#   apache.apache with permissions 0640 for the PEM and 0644 for the CRT.
#
# - Figure out the status of the bundled 'xmlseclibs.php', we use 1.3.0 from
#   upstream now in this package
#   ISSUE: http://code.google.com/p/simplesamlphp/issues/detail?id=480
#
# - Deal with bundled JavaScript (jquery, jquery-ui, ...) and also image sets?
# 
# - Make the log to file in /var/log/simplesamlphp actually work (permissions + 
#   SELinux)
#
# - Allow Apache to write to /var/lib/simplesamlphp/metadata (permissions + 
#   SELinux) for the "metarefresh" plugin
#
# - Include a README.dist or similar file explaining the configuration specific
#   items for Fedora (and SELinux)
#
# - Maybe prepare a cron example file (for metarefresh)
#
# - Figure out all licenses used in simpleSAMLphp. Debian package list some
#
# - Figure out what to do with the tmp file location, should this really be 
#   package specific e.g in /var/lib/simplesamlphp/tmp?
#

Name:		simplesamlphp
Version:	1.8.2
Release:	4%{?dist}
Summary:	PHP SAML 2.0 service provider and identity provider

Group:		Applications/Internet
License:	LGPLv2
URL:		http://simplesamlphp.org/
Source0:	http://simplesamlphp.googlecode.com/files/simplesamlphp-%{version}.tar.gz
Source1:	simplesamlphp-httpd-conf

# ISSUE: http://code.google.com/p/simplesamlphp/issues/detail?id=476
# COMMIT: http://code.google.com/p/simplesamlphp/source/detail?r=3030
Patch0:         simplesamlphp_secretsalt_warning.patch

BuildRoot:	%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

Requires:	webserver
Requires:	php >= 5.2.0
Requires:	php-ldap
Requires:	php-xml
Requires:	php-pdo
Requires:	php-mcrypt
Requires:	php-mysql
Requires:	php-pecl-radius

# php-pear-Auth-OpenID is not (yet) packaged in EPEL :(
Requires:	php-pear-Auth-OpenID
Requires:	php-xmlseclibs

BuildArch:	noarch
 
%description
SimpleSAMLphp is an award-winning application written in native PHP 
that deals with authentication. The project is led by UNINETT, has a 
large user base, a helpful user community and a large set of 
external contributors.

SimpleSAMLphp is having a main focus on providing support for:

    SAML 2.0 as a Service Provider.
    SAML 2.0 as a Identity Provider.

But also supports some other identity protocols, such as Shibboleth 
1.3, A-Select, CAS, OpenID, WS-Federation and OAuth.

%prep
%setup -q

%patch0 -p1

# fix execute permission on some files (shamelessly taken from Debian package)
find . -type f -executable -not -path '*/bin/*' | xargs chmod -x

# remove bundled php-pear-Auth-OpenID and php-xmlseclibs
rm -rf lib/Auth
rm -rf lib/xmlseclibs.php

%build

%install
rm -rf ${RPM_BUILD_ROOT}

mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}
mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/pki/%{name}
mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/attributemap
mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/metadata
mkdir -p ${RPM_BUILD_ROOT}%{_datadir}/%{name}
mkdir -p ${RPM_BUILD_ROOT}%{_localstatedir}/lib/%{name}
mkdir -p ${RPM_BUILD_ROOT}%{_localstatedir}/lib/%{name}/data
mkdir -p ${RPM_BUILD_ROOT}%{_localstatedir}/lib/%{name}/metadata

install -m 0644 -D -p %{SOURCE1} ${RPM_BUILD_ROOT}%{_sysconfdir}/httpd/conf.d/%{name}.conf

cp -pr config-templates/* ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}
cp -pr metadata-templates/* ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/metadata
cp -pr attributemap/* ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/attributemap
cp -pr cert/* ${RPM_BUILD_ROOT}%{_sysconfdir}/pki/%{name}

sed -i "s|'baseurlpath'           => 'simplesaml/'|'baseurlpath'           => 'simplesamlphp/'|g" ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/config.php
sed -i "s|'datadir'               => 'data/'|'datadir'               => '/var/lib/simplesamlphp/data/'|g" ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/config.php
sed -i "s|'loggingdir'            => 'log/'|'loggingdir'            => '/var/log/simplesamlphp/'|g" ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/config.php
sed -i "s|'certdir'               => 'cert/'|'certdir'               => '/etc/pki/simplesamlphp/'|g" ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/config.php

cp -pr bin ${RPM_BUILD_ROOT}%{_datadir}/%{name}/
cp -pr dictionaries ${RPM_BUILD_ROOT}%{_datadir}/%{name}/
cp -pr lib ${RPM_BUILD_ROOT}%{_datadir}/%{name}/
cp -pr modules ${RPM_BUILD_ROOT}%{_datadir}/%{name}/
cp -pr schemas ${RPM_BUILD_ROOT}%{_datadir}/%{name}/
cp -pr templates ${RPM_BUILD_ROOT}%{_datadir}/%{name}/
cp -pr www ${RPM_BUILD_ROOT}%{_datadir}/%{name}/

ln -sf ../../../etc/simplesamlphp ${RPM_BUILD_ROOT}%{_datadir}/simplesamlphp/config
ln -sf ../../../etc/simplesamlphp/metadata ${RPM_BUILD_ROOT}%{_datadir}/simplesamlphp/metadata
ln -sf ../../../etc/simplesamlphp/attributemap ${RPM_BUILD_ROOT}%{_datadir}/simplesamlphp/attributemap
ln -sf ../../../../usr/share/pear/Auth_OpenID ${RPM_BUILD_ROOT}%{_datadir}/simplesamlphp/lib/Auth
ln -sf ../../../../../usr/share/php/xmlseclibs/xmlseclibs.php ${RPM_BUILD_ROOT}%{_datadir}/simplesamlphp/lib/xmlseclibs.php

#%post 
#if [ ! -f /etc/pki/%{name}/server.crt ]; then
#	openssl req -subj '/CN=SAML Certificate' -newkey rsa:2048 \
#	-new -x509 -days 3652 -nodes -out /etc/pki/%{name}/server.crt -keyout \
#	/etc/pki/%{name}/server.pem > /dev/null
#fi

%clean
rm -rf ${RPM_BUILD_ROOT}

%files
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}
#%config(noreplace) %{_sysconfdir}/pki/%{name}

%{_sysconfdir}/pki/%{name}
%{_datadir}/%{name}
%{_localstatedir}/lib/%{name}
%doc docs/ COPYING

%changelog
* Sat Feb 18 2012 F. Kooman <fkooman@tuxed.net> - 1.8.2-4
- depend on external php-xmlseclibs

* Fri Feb 17 2012 F. Kooman <fkooman@tuxed.net> - 1.8.2-3
- move attributemap to /etc/simplesamlphp
- shuffle some sections, only copy dirs needed instead of removing the ones 
  we do not need

* Tue Feb 14 2012 F. Kooman <fkooman@tuxed.net> - 1.8.2-2
- remove included PHP OpenID library, use system version instead
- update Apache config to only allow localhost by default
- apply patch to warn if secretsalt is still set to the default
- move certificates to /etc/pki/simplesamlphp

* Wed Feb 11 2012 F. Kooman <fkooman@tuxed.net> - 1.8.2-1
- initial package based on previous work by Gijs Molenaar, Xander Jansen,
  Victoriano Giralt (RPM package) and Thijs Kinkhorst (Debian package).

